/***************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (directui@nokia.com)
**
** This file is part of meegotouchhome-nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at directui@nokia.com.
**
****************************************************************************/
/*!
 * @copyright Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 * @license Nokia proprietary
 */

#ifndef MEVENTFEED_H_
#define MEVENTFEED_H_

#include "meventfeedproxy.h"
#include <qglobal.h>

/*!
 * An interface to the event feed. Uses the com.nokia.home.EventFeed D-Bus
 * interface with which application developers can create and manage event
 * feed items.
 */
class MEventFeed
{
private:
    /*!
     * Constructs an interface for the event feed.
     */
    MEventFeed();

    /*!
     * Destroys an interface for the event feed.
     */
    virtual ~MEventFeed();

    //! The D-Bus proxy object for the event feed interface.
    MEventFeedProxy proxy;

public:
    /*!
     * Returns an instance of the event feed interface.
     *
     * \return an instance of the event feed interface
     */
    static MEventFeed *instance();

    /*!
     * Adds an item to the event feed.
     *
     * \param icon the icon id for the feed item or absolute path to an image file. The icon must exist when addItem() is called. If the icon image is unique its path must be unique (same path should not be reused for different images).
     * \param title the title for the feed item
     * \param body the body text for the feed item
     * \param imageList the image list for the feed item. If the images in list start with /, they're interpreted as absolute paths, otherwise as image IDs from the theme. The images must exist when addItem() is called. If an image is unique its path must be unique (same path should not be reused for different images).
     * \param timestamp timestamp for the feed item
     * \param footer the footer text for the feed item. If there is no visible text to be shown in the footer the footer should be empty.
     * \param video if true, marks that the event item contains video content. The video content is limited to one thumbnail in the image list. The thumbnail will have a play button overlay rendered on top of it.
     * \param url the url to be executed when item is clicked. Executed action for URL is the default action provided by libcontentaction for the URL's scheme.
     * \param sourceName identifier for the event source e.g. application name, which should be persistent.
     * \param sourceDisplayName the source description in localized form which will be displayed in the UI in event feed item's object menu.
     * \return unique id for the event feed item or -1 if values for the mandatory keys are not provided
     */
    qlonglong addItem(const QString &icon, const QString &title, const QString &body, const QStringList &imageList, const QDateTime &timestamp, const QString &footer, bool video, const QUrl &url, const QString &sourceName, const QString &sourceDisplayName);

    /*!
     * Removes all events with the specified source name from the event feed.
     *
     * \param sourceName identifier for the event source
     */
    void removeItemsBySourceName(const QString &sourceName);
};

#endif /* MEVENTFEED_H_ */
